## Abvieon’s Guide to Parallel Processing
The following is an excerpt from a tulpa creation guide I am currently writing.
I have taken my section on parallel processing in that guide and put it into a
separate document so I can send this to those who are looking for advice
specifically on parallel processing.

### Processing power and plurality

Although a tulpa is a separate consciousness, creating a tulpa will not increase
your brain’s total “processing power”, or the resources used to think and
process information. To put it simply, having a tulpa does not give your brain
the processing power of two brains. This means that your brain’s existing
processing power must be shared, divided and swapped between you and your tulpa.

How does processing power work when it comes to having more than one person in a
head? There are three possible configurations - sharing, swapping, and dividing.
I will walk you through a symbolic demonstration of how I believe each of these
configurations work.

Imagine two small circles, one labeled “host” and the other labeled “tulpa”.
Now, imagine a larger circle labeled “processing power.”

### Sharing

In the first configuration, both the host and tulpa circles are inside of the
processing power circle. This means that both the host and tulpa are conscious
but are taking in the same information and sensory input. They are both focusing
on the same thing. Each is aware of everything the other is aware of.
Interactions between the tulpa and host in this state must be alternating - if
they are having a conversation, they cannot speak at the exact same time and
will instead take turns thinking and speaking. The one not doing the thinking or
speaking at any given time will be doing nothing but observing. 

### Swapping

Either the host or tulpa circle is inside of the processing power circle and the
other is outside of it. This means that one is conscious while the other is
unconscious. This may happen if one becomes involved in a highly mentally
intensive task, forcing them to take all of the processing power for themselves
and leaving none left over for the other to use. If one has no processing power
to use for themselves, not only do they lose the ability to think, but they also
go unconscious.

### Dividing

Now, imagine that the processing power circle has been split into two separate
circles. The host circle is inside of one and the tulpa circle is inside of the
other. Because the processing power circle was split rather than multiplied,
each “half” of the circle is smaller than the original. This means that the host
and tulpa each have a smaller pool of resources to work with than if they were
in the sharing configuration. However, this configuration allows for the host
and tulpa to each think about different things simultaneously, unlike in the
sharing configuration. They will be focusing on separate things and may not be
aware of everything the other is aware of. 

### Parallel processing

The “dividing” configuration described above is what is known as “parallel
processing.” During parallel processing, the host and tulpa will be thinking
about or focusing on different things at the same time, operating in parallel to
one another. One example of such is when a host goes about their day while their
tulpa occupies themselves with something else in the mindscape. Another example
is when a tulpa has private thoughts of their own that the host cannot hear.
Parallel processing is a skill that some systems exercise by default with hardly
any effort, possessing a natural talent for it, while other systems may find it
very difficult, needing to put in significant effort to achieve it. 

Parallel processing is not to be confused with multitasking. Multitasking deals
with a single consciousness while parallel processing deals with more than one
consciousness. The word “multitasking” itself is a misnomer - a single
consciousness is a single stream of awareness and experience, and therefore
cannot have more than one focus at a time. A single consciousness can quickly
switch between different focuses, which can give off a vague impression of doing
more than one thing at a time, though that isn’t what is actually happening.
This is what multitasking actually is. When a second stream of awareness and
experience is present, that second consciousness can focus on something else at
the same time. 

Still, parallel processing is hardly a superpower of any sort - as mentioned
before, this division does not give your brain any more resources to work with
than it had prior to containing more than one consciousness. This means that it
is very difficult, for some even impossible, for a host and tulpa to be involved
in different highly mentally intensive activities simultaneously. For example,
both doing different difficult math problems. However, it is more feasible for
one to work on a math problem while the other does something far less intensive,
such as taking a walk in the mindscape. The more processing power one is using,
the less the other will have to work with. It is a balancing act.

Young or not yet well developed tulpas tend to have trouble with “grabbing”
processing power for themselves, needing their host to be directly feeding them
processing power in the form of attention in order to remain conscious. The
moment their host directs their attention elsewhere, even if it is not to
something mentally strenuous, the tulpa will go unconscious. This is a problem
as it can easily lead to the tulpa spending large chunks of time not doing
anything that could have better been used for any number of things, and does not
allow for them to be self sufficient. In order to have this not happen, the
tulpa must learn to either “latch onto” and share their host’s processing power
without their host giving them attention, or learn to divide it. The former
often happens naturally with nothing more than time and development, but the
latter will often need to be actively pursued in order to achieve. Dividing
processing power is typically more desirable than sharing it because the tulpa
will not have to constantly watch whatever the host is doing or vice versa.

### Learning to parallel process

In order to learn to parallel process, you must start small and work your way
up. Certain things in parallel processing are more difficult than others - if
you don’t have a natural affinity for parallel processing and try to jump
straight into trying to go about your day while your tulpa does activities in
the mindscape you will fail to do so, possibly frustrating yourself or leading
yourself to believe that it is not possible for you to parallel process. 

The very first thing you must do is split you and your tulpa’s observation,
taking in different sensory input at the same time. This is the first step to
break out of the standard “sharing” configuration, and is the very baseline of
all parallel processing. You will not be able to do anything more advanced until
you are able to do this. Observation and thinking are not the same thing - one
can remain conscious and aware without thinking. Observation also uses up far
less processing power than thinking does, meaning that it is easier for a host
and tulpa to observe different things simultaneously than it is for them to
think about different things simultaneously. 

####  Splitting observation

You don't have another set of eyes on the back of your head, so the best way of
doing this is by utilizing your mindscape. First, immerse yourself in the
mindscape and make sure your tulpa is as well. Then, identify an object to look
at, for example a tree. Now, identify another object - and this is important -
have it be out of the field of vision of where your own object can be seen. Also
make sure that it looks very different from the object you will be looking at.
If you are going to be looking at a pine tree, have the other object be a
deciduous tree.

Though not required, it is ideal for this activity that your mindscape is
fleshed out and consistent. This means that objects, areas, rooms, etc. and
their locations are generally the same and can be clearly recalled and
visualised with little to no mental effort. If the layout of rooms or locations
of objects in your mindscape are inconsistent or hard to remember, this activity
will probably be harder.

Some tulpas by default see things via their host’s perspective in the mindscape
even if they have a form of their own. If they do this, tell your tulpa to shift
their perspective to their own form. Have them imagine that they are seeing out
of their form’s eyes rather than yours.

Now, look at your object, and tell your tulpa to look at the other object. You
might notice that your senses start to “overlap” - you might start seeing what
you tulpa sees on top of what you are looking at, almost as if they are morphing
together  - if this happens, try to ignore what your tulpa is seeing. You can do
this by focusing more heavily on your own object. Examine its smaller details,
take note of its every little aspect. Fill your mind with observations of your
object until everything else, anything you are not choosing to focus on, is
pushed out of your awareness. Your tulpa should do the same. Try to keep this up
for as long as you can. You and your tulpa may only be able to maintain this for
seconds at a time at first, but if you continue to practice you will get better
at it. 

Splitting sensory input between you and your tulpa creates the capability for
isolated experience within your system. Isolated experience is just what it
sounds like - The tulpa being aware of things that the host is not aware of, or
vise versa. This is what allows for parallel processing to be possible. 

If you do not have a mindscape, have a very weak ability to visualize, or just
can’t succeed at this for some reason, there is another option for training this
skill that does not involve sensory imagination at all. There is a game made
specifically for training and testing parallel processing. Click on the
‘instructions’ button when you open the game to see how it works. 

#### Thought concealment

Once you have had some success with the previous exercise, you can move on to
slightly harder things. This exercise does not deal with isolating sensory
observation, it instead deals with isolating thought. 

The idea here is to have your tulpa be able to have thoughts which you are not
aware of, and for you to be able to have thoughts your tulpa is not aware of.
You should start by forming a sort of divide between mindvoice vocalization
directed at your tulpa and ordinary background thoughts within your mind.
Recognize them as being different things. One is meant to be heard by your
tulpa, the other not. You can use symbolism to form this distinction - “attach”
a certain feeling or image to the thoughts you want your tulpa to be able to
hear. Be consistent and do this every single time you talk to your tulpa, and
keep it up for a long period of time - over time your mind will start to
recognize your interactions with your tulpa as in some way being different from
your ordinary thoughts. However, this does not automatically make it so your
tulpa cannot hear certain thoughts of yours, it only establishes the necessary
separation between what you do and do not want your tulpa to hear. You and your
tulpa will need to do a bit more to actually hide certain thoughts. 

Next, your tulpa will need to teach themselves to automatically ignore and block
out any thoughts of yours that are not being “sent” along with the symbol you
chose. They can start by consciously choosing to ignore any of said thoughts -
as soon as they notice them, they should distract themselves with something else
to avoid continued awareness of them. They should think of them as being
insignificant, not worth paying attention to. If done consistently, over time
this process of ignoring said thoughts will become automatic and unconscious.
The thoughts you do not direct specifically at your tulpa will automatically
avoid your tulpa’s awareness. Your tulpa won’t need to make an effort to ignore
them any longer, as they won’t even enter your tulpa’s awareness in the first
place. The process needed for your tulpa to be able to hide certain thoughts
from you is the same as this, just with reversed roles.

I did not suggest that you instead associate a symbol with the thoughts you
don’t want your tulpa to hear because it may be annoying and more difficult to
have to associate a symbol with all of your personal thoughts - such thoughts
are typically more free-flowing and less stringently directed than thoughts you
would direct at your tulpa, so it would be more difficult to consistently
associate a symbol with them. 

####  Counting exercise

Once you have had some success with thought concealment, this next exercise
becomes possible. What you will do here is have your tulpa count in private
thoughts - thoughts you can’t hear - after which you will check on them to
verify that they have actually been counting outside of your awareness. 

First, find a timer, preferably a digital one. Your tulpa should become familiar
with the pace of the timer, internalizing how long each second takes. This is
the pace your tulpa should count at. If your tulpa counts too slow or too fast
relative to the timer, it will be more difficult to see whether or not your
tulpa did the exercise correctly. 

Use the stopwatch mode on the timer. When you press start should be the moment
your tulpa starts counting. Now, you need to put the timer somewhere you cannot
see it. If it makes noise or ticks, put it somewhere you can’t hear it. 

Now, go do something for a minute or two that does not require a great deal of
mental effort. Maybe read some of a book you’re read before or go on a short
walk. If you do not occupy yourself with something else while your tulpa counts
you are at a greater risk of accidentally becoming aware of their thought
process. But, it cannot be mentally strenuous, otherwise you risk stealing too
much processing power from your tulpa, the processing power they need in order
to count. 

Now, go back to the timer - without looking at the face so you can’t see what
number it is at - and press stop. Your tulpa should stop counting when you do
this. Before looking at the number on the timer, ask your tulpa what number they
counted to. Now, flip the timer around and see what it stopped at. If the number
your tulpa counted to is very close to the number of seconds the timer was at,
this means your tulpa was successfully able to count while you did something
else at the same time. Counting may take very little mental effort, but it is a
start. This skill can evolve into far more advanced things. 

You can increase the difficulty of this exercise by increasing the amount of
time your tulpa counts for or doing something more mentally strenuous while they
count. Of course, you can also replace the counting with a more mentally
strenuous activity. Once you are good enough at this, your tulpa will be able to
do a wide variety of things outside of your awareness.

### Self sufficiency

Forcing doesn’t have to last forever. You may not need to continue putting work
into maintaining your tulpa and keeping them around, or at least anything that
feels like work. It’s possible to stop forcing entirely but have your tulpa
continue existing as they have been without in any way regressing or becoming
less active. This is achieved by your tulpa becoming self-sufficient.

Self sufficiency is possible only when your tulpa is able to hold onto
processing power for themselves without you giving it to them. They must be able
to be conscious at their own discretion, not only when you are paying attention
to them. As mentioned before, there are two different ways for your tulpa to do
this- sharing your processing power or dividing it. 

Because I already went over parallel processing, I’ll explain how your tulpa can
share your processing power. The sharing of processing power is typically easier
and more prone to occuring naturally than parallel processing is, but it is
still helpful to know how to “brute force” it in case it doesn’t end up
happening naturally as your tulpa develops.

When your tulpa shares your processing power, they will be sharing your
experience at all times, staying with you throughout the day no matter what you
are doing. Seeing what you are seeing, hearing what you are hearing, etc. This
replaces the function that your forcing and attention previously had. They won’t
need you to direct thoughts and stimuli towards them, because they will be
automatically receiving it by themselves. Sharing processing power works best
when your tulpa is aware of your physical body and its senses rather than the
mindscape and their form within the mindscape. So, in order for your tulpa to do
this they should first learn to be connected to your senses if that is not
already a regular thing for them. 

To start off, have a long active forcing session so your tulpa is as present and
mentally active as possible. Then, start passive forcing immediately afterwards
while you go and do something else. Maybe start out with something that isn’t
very mentally demanding. At this point your tulpa should connect to your senses
if they weren’t already. As you passive force, gradually start paying less and
less attention to your tulpa. Space out your conversation so that wider gaps of
time go in-between you talking to one another. It’s important that your tulpa do
anything they can to stay awake and thinking during these gaps. If they have
difficulty forming their own thoughts to keep themselves busy, they can resort
to examining your physical environment, taking note of every detail. Or, they
can just listen to your thoughts if you haven’t practiced thought concealment. 

After awhile, stop talking to and paying attention to your tulpa entirely. If
successful, your tulpa should still be conscious. In this state, a tulpa will be
able to chime in and talk to you at any time without prompting. In a way they
will be “lurking in the background,” present yet not always within your
awareness. A tulpa who is proficient enough at this will be able to do this
24/7, minus when you are asleep, of course. 

This should go without saying, but you should not use this as a way to entirely
abandon your tulpa. It should only be used to reduce the workload of having a
tulpa by mostly removing the maintenance aspect. Even if your tulpa is perfectly
self sufficient, chances are they will still want to spend some of their time
with you. It is important that you still acknowledge them and talk to them every
once in awhile. This is especially true if you have just one tulpa, as your
tulpa will need some socialization in their life in order to stay happy and
mentally healthy.
